import { Dispatch, MutableRefObject, SetStateAction, useCallback } from 'react';

import { ColorUtils, styled } from '@nuskin/foundation-theme';

import { NsTypography, OptionsProps } from '../../';

const { getGenomeColor } = ColorUtils;
export const ListStyled = styled.div`
    display: flex;
    width: 100%;
    flex-direction: row;
    align-items: center;
    gap: 10px;
    padding: 0;
    margin: 4px 8px;
    cursor: pointer;
    &:hover {
        background: ${({ theme }) => getGenomeColor(theme, 'A10')};
    }
`;

type SeeMoreButtonProps = {
    text?: string;
    show?: boolean;
    onSeeMore?(): void;
    options: OptionsProps[];
    setScrollTopPosition: Dispatch<SetStateAction<number>>;
    listboxRef: MutableRefObject<HTMLUListElement | null>;
};

export const SeeMoreButton = (props: SeeMoreButtonProps) => {
    const {
        show = false,
        text = 'See More Results',
        onSeeMore,
        options,
        listboxRef,
        setScrollTopPosition,
    } = props || {};

    const handleSeeMore = useCallback(() => {
        /*  Remember the current scroll position */
        if (options?.length > 0 && listboxRef?.current) {
            const lastScrollPosition = listboxRef.current?.scrollTop;
            if (lastScrollPosition) {
                setScrollTopPosition(lastScrollPosition);
            }
        }
        if (typeof onSeeMore === 'function') {
            onSeeMore();
        }
    }, [listboxRef, onSeeMore, options?.length, setScrollTopPosition]);
    if (!show) {
        return null;
    }
    return (
        <ListStyled className="text-left p-0" onClick={handleSeeMore}>
            <NsTypography
                data-testid="autocomplete-loadmore-id"
                variant="body-m"
                decoration="underline"
                className="cursor-pointer"
            >
                {text}
            </NsTypography>
        </ListStyled>
    );
};
