import Box from '@mui/material/Box';
import { NsImage } from '../';
import { styled } from '@nuskin/foundation-theme';

type NsPostProps = {
    text: string;
    body: string;
    backgroundImageUrl: string;
    backgroundImageAlt: string;
    className?: string;
};

const CardContainer = styled(Box)(() => {
    return {
        backgroundClip: 'border-box',
        display: 'flex',
        flexDirection: 'column' as 'column',
        wordWrap: 'break-word' as 'break-word',
        position: 'relative',
        overflow: 'hidden',
        maxWidth: '165px',
        height: '272px',
        backgroundColor: '#fff',
        '.image': {
            height: '180px',
            overflow: 'hidden',
            objectFit: 'contain',
        },
        '.content': {
            padding: '20px',
            display: 'flex',
            flexDirection: 'column',
            minHeight: '92px',
            maxHeight: '92px',
            justifyContent: 'space-around',
        },
        '.body-title': {
            fontSize: '18px',
            fontWeight: 600,
            display: '-webkit-box',
            '-webkit-box-orient': 'vertical',
            '-webkit-line-clamp': '1',
            overflow: 'hidden',
            textOverflow: 'ellipsis',
        },
        '.body-text': {
            fontSize: '12px',
            fontWeight: 700,
            display: '-webkit-box',
            '-webkit-box-orient': 'vertical',
            '-webkit-line-clamp': '1',
            overflow: 'hidden',
            textOverflow: 'ellipsis',
            color: '#8C8C8C',
        },
    };
});

const NsPost = ({ text, body, backgroundImageUrl, backgroundImageAlt, className }: NsPostProps) => {
    return (
        <CardContainer className={className} data-testid="post-card">
            <div className="image">
                <NsImage height={'100%'} width={'auto'} alt={backgroundImageAlt} src={backgroundImageUrl} />
            </div>
            <div className="content">
                <article className="body-title">{text}</article>
                <article className="body-text">{body}</article>
            </div>
        </CardContainer>
    );
};
export default NsPost;
