import type { StoryObj, Meta } from '@storybook/react';
import NsEmailSimple from './NsEmailSimple';
import { within } from '@storybook/testing-library';
import { expect } from '@storybook/jest';
import { withCenterDecorator } from '@/stories/decorators/withCenterDecorator';

async function checkEmail() {
    const isServiceValid = Promise.resolve(true);
    const isEmailAvailable = Promise.resolve(true);
    return [isServiceValid, isEmailAvailable];
}
type ComponentType = typeof NsEmailSimple;
type Story = StoryObj<ComponentType>;
type MetaStory = Meta<ComponentType>;

export default {
    component: NsEmailSimple,
    title: 'Components/Inputs/NsEmailSimple',
    decorators: [withCenterDecorator],
    play: ({ canvasElement }) => {
        const canvas = within(canvasElement);
        const el = canvas.getByTestId('email-field-test');
        expect(el).toBeInTheDocument();
    },

    argTypes: {
        disabled: {
            description: 'Indicates whether the email field is enabled/disabled',
        },
        label: {
            description: 'Label of the email component',
        },
        required: {
            description: 'Indicates whether the email field is mandatory or not',
        },
        maxLength: {
            description: 'Maximum number of characters allowed',
        },
        invalidEmailMessage: {
            description: 'Displayed when an invalid email is entered',
        },
        dupedEmailMessage: {
            description: 'Displayed when a duplicate email is entered',
        },
        requiredErrorMessage: {
            description: 'Displayed when email is not entered',
        },
    },
    args: {
        disabled: false,
        label: 'Email',
        required: true,
        maxLength: 50,
        invalidEmailMessage: 'Please enter a valid email',
        dupedEmailMessage: 'Email ID already exists',
        requiredErrorMessage: 'Email field is required',
        checkEmail: checkEmail,
    },
} as MetaStory;

export const NsEmail: Story = {};
