import { NsIcon, NsIconNameType } from '../icon';
import { InputAdornment } from '@mui/material';
import { fieldStateType } from './types.d';
import { ReactNode } from 'react';

type IconMapType = {
    [key: string]: NsIconNameType;
};

const iconNameForFieldState: IconMapType = {
    error: 'error',
    success: 'success',
};
type props = {
    disabled?: boolean;
    fieldState: fieldStateType;
    iconStart: ReactNode;
    iconEnd: ReactNode;
};
/**
 * Note: we are hiding the Adornment icons in case input is disabled
 * @param param0
 * @returns
 */
export type AdornmentPropsType = {
    startAdornment?: ReactNode;
    endAdornment?: ReactNode;
}
export const getAdornmentProps = ({ disabled, fieldState, iconStart, iconEnd }: props) => {
    const icons = {
        startAdornment: iconStart ? <InputAdornment position="start">{iconStart}</InputAdornment> : null,
        endAdornment: iconEnd ? <InputAdornment position="end">{iconEnd}</InputAdornment> : null,
    };
    if (disabled) {
        return {};
    } else {
        if (fieldState === 'error' || fieldState === 'success') {
            return {
                ...icons,
                endAdornment: (
                    <InputAdornment position="end">
                        <NsIcon name={iconNameForFieldState[fieldState]} />
                    </InputAdornment>
                ),
            };
        } else {
            return icons;
        }
    }
};
