/**
 * @name NsLink.tsx
 * @description Exports one components - NsLink
 */

import React, { PropsWithChildren } from 'react';

import { StyledLink, StyledNextLink } from './NsLink.styled';
import { NsLinkProps } from './types.d';

const NsLink = (props: PropsWithChildren<NsLinkProps>) => {
    const {
        className,
        href,
        underlineOnHover,
        target,
        isSsr = false,
        additionalProps,
        children,
        passHref,
        prefetch,
        disabled,
    } = props;

    if (isSsr) {
        return (
            <StyledNextLink
                className={className}
                href={href}
                $underlineOnHover={underlineOnHover}
                passHref={passHref}
                prefetch={prefetch}
                disabled={disabled}
                {...additionalProps}
            >
                {children}
            </StyledNextLink>
        );
    }

    return (
        <StyledLink
            className={className}
            href={href}
            disabled={disabled}
            $underlineOnHover={underlineOnHover}
            target={target}
            {...additionalProps}
        >
            {children}
        </StyledLink>
    );
};

export default NsLink;
