import React from 'react';
import { render, fireEvent, screen } from '@testing-library/react';
import { NsRadioGroup } from './';
import { FoundationTheme } from '@nuskin/foundation-theme';

describe('NsRadioGroup', () => {
    const options = [
        { id: 'Option1', label: 'Option 1', value: 'Option1' },
        { id: 'Option2', label: 'Option 2', value: 'Option2' },
        { id: 'Option3', label: 'Option 3', value: 'Option3' },
    ];

    const props = {
        disable: false,
        items: options,
        name: 'test',
        label: 'I choose to signup as',
        color: '#272525' as FoundationTheme.PaletteColors,
        helperText: 'help text for more information',
        size: 24,
        labelFontSize: 16,
        additionalProps: {
            testid: 'radio-group',
        },
    };
    const onChange = jest.fn();

    it('1. renders options correctly', () => {
        render(<NsRadioGroup {...props} onChange={onChange} />);

        options.forEach((option) => {
            const radioOption = screen.getByLabelText(option.label) as HTMLInputElement;
            expect(radioOption).toBeInTheDocument();
            expect(radioOption.value).toBe(option.value);
        });
    });
    it('2. renders options correctly without additional slot', () => {
        render(<NsRadioGroup {...props} onChange={onChange} helperText={''} />);

        options.forEach((option) => {
            const radioOption = screen.getByLabelText(option.label) as HTMLInputElement;
            expect(radioOption).toBeInTheDocument();
            expect(radioOption.value).toBe(option.value);
        });
    });

    it('3. calls OnChange when selecting option', () => {
        render(<NsRadioGroup {...props} onChange={onChange} />);

        const radioOption = screen.getByLabelText('Option 2') as HTMLInputElement;
        fireEvent.click(radioOption);
        expect(onChange).toHaveBeenCalledTimes(1);
    });

    it('4. does not call Onchange when the same option is clicked', () => {
        const onChange = jest.fn();
        render(<NsRadioGroup {...props} onChange={onChange} />);

        const radioOption = screen.getByLabelText('Option 1') as HTMLInputElement;
        fireEvent.click(radioOption);
        expect(onChange).not.toHaveBeenCalled();
    });
});
